@@ -66,6 +66,8 @@ def get_type(t: SpectreType, name = None):
         return 'String'
     if t is SpectreType.UUID:
         return 'UUID'
+    if t is SpectreType.BINARY:
+        return 'byte[]'
     raise UnknownTypeException(f'Unknown Spectre type (Java mapping not yet implemented): {t.name}')
 
 def generate(config: Config, path):
