@@ -18,8 +18,9 @@ class SpectreType(Enum):
     ENUM = 4
     TIMESTAMP = 5
     UUID = 6
+    BINARY = 7
     #UNDEFINED has to go last or it will mess up prompts and typing. Value does not matter, only relative position has to be last
-    UNDEFINED = 7
+    UNDEFINED = 8
 
     def __repr__(self):
         return self.name
@@ -27,6 +28,8 @@ class SpectreType(Enum):
 @dataclass
 class Field:
     name: str = None
+    #This indicates a primary key in database schemas. If multiple fields have this it means composite ID where this is supported
+    primary_key: bool = False
     type: SpectreType = SpectreType.UNDEFINED
     description: str = None
     required: bool = False
@@ -64,6 +67,10 @@ class Field:
                 'validator': lambda val: isinstance(val, bool), 
                 'value': lambda val: val
             },
+            'primary_key': {
+                'validator': lambda val: isinstance(val, bool), 
+                'value': lambda val: val
+            },
             'example': {
                 'validator': lambda val: True,
                 'value': lambda val: val
